OpenStack Configuration Discovery
=================================

This is a configuration discovery tool for OpenStack.

Contents:

.. toctree::
   :maxdepth: 1

   releases

Getting Started
---------------

* Check out `the wiki`_
* Read the source `on GitHub`_

.. _the wiki: https://wiki.openstack.org/Satori

Contributing
============

Code is hosted `on GitHub`_. Submit bugs to the satori project
on  `Launchpad`_. Submit code to the openstack/satori project
using `Gerrit`_.

.. _on GitHub: https://github.com/stackforge/satori
.. _Launchpad: https://launchpad.net/satori
.. _Gerrit: http://wiki.openstack.org/GerritWorkflow

Index
=====

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
